==> service-proxy-core-4.6.4-sources.jar: com/predic8/membrane/core/http/xml/Query.java <==
/* Copyright 2011 predic8 GmbH, www.predic8.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. */
package com.predic8.membrane.core.http.xml;

import java.util.ArrayList;
import java.util.List;

import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.XMLStreamWriter;

import com.predic8.membrane.core.config.AbstractXmlElement;

public class Query extends AbstractXmlElement {
	public static final String ELEMENT_NAME = "query";

	private List<Param> params = new ArrayList<Param>();

	@Override
	protected void parseChildren(XMLStreamReader token, String child) throws Exception {
		if (Param.ELEMENT_NAME.equals(child)) {
			params.add((Param)new Param().parse(token));
		}
	}

	@Override
	public void write(XMLStreamWriter out) throws XMLStreamException {
		out.writeStartElement(ELEMENT_NAME);

		for (Param c : params) {
			c.write(out);
		}

		out.writeEndElement();
	}

	public List<Param> getParams() {
		return params;
	}

	public void setParams(List<Param> params) {
		this.params = params;
	}

	@Override
	protected String getElementName() {
		return ELEMENT_NAME;
	}


}

==> service-proxy-core-5.1.0-sources.jar: com/predic8/membrane/core/http/xml/Query.java <==
/* Copyright 2011 predic8 GmbH, www.predic8.com

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. */
package com.predic8.membrane.core.http.xml;

import java.util.ArrayList;
import java.util.List;

import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.XMLStreamWriter;

import com.predic8.membrane.core.config.AbstractXmlElement;

public class Query extends AbstractXmlElement {
	public static final String ELEMENT_NAME = "query";

	private List<Param> params = new ArrayList<>();

	@Override
	protected void parseChildren(XMLStreamReader token, String child) throws Exception {
		if (Param.ELEMENT_NAME.equals(child)) {
			params.add((Param)new Param().parse(token));
		}
	}

	@Override
	public void write(XMLStreamWriter out) throws XMLStreamException {
		out.writeStartElement(ELEMENT_NAME);

		for (Param c : params) {
			c.write(out);
		}

		out.writeEndElement();
	}

	public List<Param> getParams() {
		return params;
	}

	public void setParams(List<Param> params) {
		this.params = params;
	}

	@Override
	protected String getElementName() {
		return ELEMENT_NAME;
	}


}
